skillfed

triton

A language and compiler for custom Deep Learning operations

triton Permissive license Active 19,937 v3.7.1 released

Install

triton on PyPI

pip

pip install triton

uv

uv add triton

poetry

poetry add triton

Package facts

License not declared (permissive)
Python support supports the current Python release (<3.15,>=3.10)
Install friction medium — platform-specific wheel
Runtime dependencies 1 — importlib-metadata
Maintenance actively maintained — 57 days since the last release
Last repo commit
First released
Popularity one of the top 1,000 most-downloaded packages on PyPI (30-day window, as of 2026-08-13)
Known vulnerabilities none known (OSV.dev, checked 2026-08-13)

Evidence: triton-3.7.1-cp310-cp310-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton-3.7.1-cp310-cp310-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton-3.7.1-cp311-cp311-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton-3.7.1-cp311-cp311-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton-3.7.1-cp312-cp312-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton-3.7.1-cp312-cp312-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton-3.7.1-cp313-cp313-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton-3.7.1-cp313-cp313-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton-3.7.1-cp314-cp314-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton-3.7.1-cp314-cp314-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton-3.7.1-cp314-cp314t-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton-3.7.1-cp314-cp314t-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl

Keywords: Compiler, Deep Learning

Development Status :: 4 - BetaIntended Audience :: DevelopersLicense :: OSI Approved :: MIT LicenseProgramming Language :: Python :: 3.10Programming Language :: Python :: 3.11Programming Language :: Python :: 3.12Programming Language :: Python :: 3.13Programming Language :: Python :: 3.14Topic :: Software Development :: Build Tools

About triton

from the package's own PyPI description — quoted content, verbatim

Documentation Nightly Wheels
Documentation (image) Wheels (image)

Triton Conference 2025

Triton Banner (image)

The 3rd Triton Developer Conference took place on October 21, 2025 at the Microsoft Silicon Valley Campus in Mountain View, California.

Conference Materials

Conference recordings and materials are now available online:

For previous conference materials, see: - 2024 Conference Materials - 2023 Conference Materials

Triton

This is the development repository...

Read as markdown · JSON record · Source repository · Homepage

AI interpretation — verify before relying

AI-generated interpretation of the package facts above; every digit, version, license, or vulnerability id it cites is grounded in the facts already shown on this page

Triton is a language and compiler for writing highly efficient custom deep-learning primitives, enabling GPU and CPU code generation at higher productivity than CUDA with greater flexibility than domain-specific languages.

Medium install friction due to platform-specific wheels (x86_64 and aarch64 Linux only) and compiled dependencies; however, active maintenance with recent releases (57 days since 3.7.1) suggests reliable binary availability.

Permissive license treatment allows commercial and private use without restriction, typical of open-source deep-learning infrastructure projects.

Usage

pip install triton
import triton
import triton.language as tl

@triton.jit
def add_kernel(x_ptr, y_ptr, output_ptr, n, BLOCK_SIZE: tl.constexpr):
    pid = tl.program_id(axis=0)
    block_start = pid * BLOCK_SIZE
    offsets = block_start + tl.arange(0, BLOCK_SIZE)
    mask = offsets < n
    x = tl.load(x_ptr + offsets, mask=mask)
    y = tl.load(y_ptr + offsets, mask=mask)
    output = x + y
    tl.store(output_ptr + offsets, output, mask=mask)

Requires Python 3.10–3.14; Linux x86_64 or aarch64 platform; GPU support requires CUDA-capable hardware or compatible accelerator.

Verdict: Triton is actively maintained with recent releases and no known vulnerabilities. Install friction is moderate due to platform specificity, but permissive licensing and broad Python version support (3.10–3.14) make it accessible for GPU-accelerated workloads. Suitable for production use where custom kernel performance is critical.

Needs verification

  • Community adoption scale and production deployment prevalence
  • Specific CUDA version compatibility requirements not stated in fact sheet
  • Performance characteristics and optimization guidance for different hardware targets
  • Whether pre-built wheels cover all target deployment platforms beyond Linux x86_64/aarch64
GPU kernel compiler for deep learningcustom neural network operationsCUDA alternative high-levelMLIR-based GPU code generationefficient deep learning primitivestiled neural network compilerGPU programming productivity

Similar packages